@@ -2,11 +2,16 @@ package Method::Workflow::SPEC::AfterAll;
 use strict;
 use warnings;
 
-use Method::Workflow;
-use base 'Method::Workflow::SPEC::Base';
+use Method::Workflow::SubClass;
+use Carp qw/croak/;
 
 keyword 'after_all';
 
+sub init {
+    croak shift->keyword . " can only be used within a describe {} block."
+        unless parent_workflow()->isa( 'Method::Workflow::SPEC' );
+}
+
 1;
 
 =head1 FENNEC PROJECT
